==> v21.04.tar.gz: bookstack/resources/lang/es/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Atrás',
    'save' => 'Guardar',
    'continue' => 'Continuar',
    'select' => 'Seleccionar',
    'toggle_all' => 'Marcarlos todos',
    'more' => 'Más',

    // Form Labels
    'name' => 'Nombre',
    'description' => 'Descripción',
    'role' => 'Rol',
    'cover_image' => 'Imagen de portada',
    'cover_image_description' => 'Esta imagen debe ser aproximadamente de 440x250px.',
    
    // Actions
    'actions' => 'Acciones',
    'view' => 'Ver',
    'view_all' => 'Ver todos',
    'create' => 'Crear',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Borrar',
    'delete_confirm' => 'Confirmar borrado',
    'search' => 'Buscar',
    'search_clear' => 'Limpiar búsqueda',
    'reset' => 'Resetear',
    'remove' => 'Remover',
    'add' => 'Añadir',
    'fullscreen' => 'Pantalla completa',

    // Sort Options
    'sort_options' => 'Opciones de ordenación',
    'sort_direction_toggle' => 'Cambiar el Orden',
    'sort_ascending' => 'Ordenar Ascendentemente',
    'sort_descending' => 'Ordenar Descendentemente',
    'sort_name' => 'Nombre',
    'sort_default' => 'Default',
    'sort_created_at' => 'Fecha de Creación',
    'sort_updated_at' => 'Fecha de Modificación',

    // Misc
    'deleted_user' => 'Usuario borrado',
    'no_activity' => 'Ninguna actividad para mostrar',
    'no_items' => 'No hay elementos disponibles',
    'back_to_top' => 'Volver arriba',
    'toggle_details' => 'Alternar detalles',
    'toggle_thumbnails' => 'Alternar miniaturas',
    'details' => 'Detalles',
    'grid_view' => 'Vista en Cuadrícula',
    'list_view' => 'Vista en Lista',
    'default' => 'Predeterminada',
    'breadcrumb' => 'Rastro de migas de pan',

    // Header
    'profile_menu' => 'Menú de Perfil',
    'view_profile' => 'Ver Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Oscuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Información',
    'tab_content' => 'Contenido',

    // Email Content
    'email_action_help' => 'Si está teniendo problemas clicando en el botón ":actionText", copie y pegue la siguiente URL en su navegador web:',
    'email_rights' => 'Todos los derechos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privacidad',
    'terms_of_service' => 'Términos de Servicio',
];

==> v21.05.tar.gz: bookstack/resources/lang/es/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Atrás',
    'save' => 'Guardar',
    'continue' => 'Continuar',
    'select' => 'Seleccionar',
    'toggle_all' => 'Marcarlos todos',
    'more' => 'Más',

    // Form Labels
    'name' => 'Nombre',
    'description' => 'Descripción',
    'role' => 'Rol',
    'cover_image' => 'Imagen de portada',
    'cover_image_description' => 'Esta imagen debe ser aproximadamente de 440x250px.',
    
    // Actions
    'actions' => 'Acciones',
    'view' => 'Ver',
    'view_all' => 'Ver todos',
    'create' => 'Crear',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Borrar',
    'delete_confirm' => 'Confirmar borrado',
    'search' => 'Buscar',
    'search_clear' => 'Limpiar búsqueda',
    'reset' => 'Resetear',
    'remove' => 'Remover',
    'add' => 'Añadir',
    'fullscreen' => 'Pantalla completa',
    'favourite' => 'Añadir a favoritos',
    'unfavourite' => 'Eliminar de favoritos',
    'next' => 'Siguiente',
    'previous' => 'Anterior',

    // Sort Options
    'sort_options' => 'Opciones de ordenación',
    'sort_direction_toggle' => 'Cambiar el Orden',
    'sort_ascending' => 'Ordenar Ascendentemente',
    'sort_descending' => 'Ordenar Descendentemente',
    'sort_name' => 'Nombre',
    'sort_default' => 'Predeterminada',
    'sort_created_at' => 'Fecha de Creación',
    'sort_updated_at' => 'Fecha de Modificación',

    // Misc
    'deleted_user' => 'Usuario borrado',
    'no_activity' => 'Ninguna actividad para mostrar',
    'no_items' => 'No hay elementos disponibles',
    'back_to_top' => 'Volver arriba',
    'toggle_details' => 'Alternar detalles',
    'toggle_thumbnails' => 'Alternar miniaturas',
    'details' => 'Detalles',
    'grid_view' => 'Vista en Cuadrícula',
    'list_view' => 'Vista en Lista',
    'default' => 'Predeterminada',
    'breadcrumb' => 'Rastro de migas de pan',

    // Header
    'header_menu_expand' => 'Expandir el Menú de la Cabecera',
    'profile_menu' => 'Menú de Perfil',
    'view_profile' => 'Ver Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Oscuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Información',
    'tab_info_label' => 'Pestaña: Mostrar Información Secundaria',
    'tab_content' => 'Contenido',
    'tab_content_label' => 'Pestaña: Mostrar Contenido Primario',

    // Email Content
    'email_action_help' => 'Si está teniendo problemas clicando en el botón ":actionText", copie y pegue la siguiente URL en su navegador web:',
    'email_rights' => 'Todos los derechos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privacidad',
    'terms_of_service' => 'Términos de Servicio',
];
